MethodChannelFlutterDeviceSpecs class
An implementation of FlutterDeviceSpecsPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- FlutterDeviceSpecsPlatform
- MethodChannelFlutterDeviceSpecs
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getBatteryInfo(
) → Future< BatteryInfo?> -
Retrieves battery information.
override
-
getDeviceInfo(
) → Future< DeviceInfo> -
Retrieves comprehensive device specifications.
override
-
getMemoryInfo(
) → Future< MemoryInfo> -
Retrieves isolated memory information.
override
-
getNetworkInfo(
) → Future< NetworkInfo> -
Retrieves network state snapshot.
override
-
getPlatformVersion(
) → Future< String?> -
Platform version check method.
override
-
getSensorInfo(
) → Future< SensorInfo> -
Retrieves sensor availability information.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited