FlutterDeviceSpecsPlatform class abstract
Platform interface for flutter_device_specs.
- Inheritance
-
- Object
- PlatformInterface
- FlutterDeviceSpecsPlatform
- Implementers
Constructors
- FlutterDeviceSpecsPlatform()
- Constructs a FlutterDeviceSpecsPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getBatteryInfo(
) → Future< BatteryInfo?> - Retrieves battery information.
-
getDeviceInfo(
) → Future< DeviceInfo> - Retrieves comprehensive device specifications.
-
getMemoryInfo(
) → Future< MemoryInfo> - Retrieves isolated memory information.
-
getNetworkInfo(
) → Future< NetworkInfo> - Retrieves network state snapshot.
-
getPlatformVersion(
) → Future< String?> - Platform version check method.
-
getSensorInfo(
) → Future< SensorInfo> - Retrieves sensor availability information.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ FlutterDeviceSpecsPlatform
-
The default instance of FlutterDeviceSpecsPlatform to use.
getter/setter pair